@@ -1,17 +1,17 @@
 use super::*;
 
-pub fn print(title: &Title, msg: &str) {
+pub fn print(title: &str, msg: &str) {
     print!("{}", format(&FmtLevel::Plain, title, msg))
 }
 
-pub fn println(title: &Title, msg: &str) {
+pub fn println(title: &str, msg: &str) {
     println!("{}", format(&FmtLevel::Plain, title, msg))
 }
 
-pub fn eprint(title: &Title, msg: &str) {
+pub fn eprint(title: &str, msg: &str) {
     eprint!("{}", format(&FmtLevel::Error, title, msg))
 }
 
-pub fn eprintln(title: &Title, msg: &str) {
+pub fn eprintln(title: &str, msg: &str) {
     eprintln!("{}", format(&FmtLevel::Error, title, msg))
 }
